"""
We-Sci's tools for researchers.

modules available:
==================

* Logger - Log input, code and outputs of python scientific research scripts,
           to be used with We-Sci's web platform (currently in closed beta)

Please email contact@we-sci.com for more info

"""
from wesci.logger import Logger
